@@ -1,7 +1,7 @@
 ;;; mousetrap.jl -- Zoom the mouse to any place with few keystrokes.
 
 ;; Author: Fernando Carmona Varo  <ferkiwi@gmail.com>
-;; Maintainer: Christopher Roy Bratusek <nano@tuxfamily.org>
+;; Maintainer: Christopher Roy Bratusek <nano@jpberlin.de>
 ;; Version: 0.7
 
 ;; This file is free software; you can redistribute it and/or modify
@@ -121,7 +121,7 @@
 
   (define-window-outliner 'crosshair draw-crosshair-outline)
 
-  ;; prevent edge actions from beeing invoked while mousetrapping
+  ;; prevent edge actions from being invoked while mousetrapping
   (defvar while-mousetrap nil)
   (defvar server-grabbed nil)
 
