@@ -16,7 +16,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with sawfish; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301 USA.
 
 (define-structure sawfish.wm.commands.move-resize
 
@@ -24,6 +25,8 @@
 	    resize-window-interactively
 	    move-selected-window
 	    resize-selected-window
+	    resize-window-frame-to
+	    resize-window-prompt
 	    double-window-size
 	    halve-window-size
 	    move-window-center)
@@ -88,6 +91,16 @@
     :tooltip "When moving a window, this option lets you align one of \
 its edges with an edge of another window.")
 
+  (defcustom marked-cursor-shape 'clock
+    "Cursor shape if a window is marked to added as tab."
+    :type (choice arrow box_spiral center_ptr circle cross cross_reverse
+                  crosshair diamond_cross dotbox clock double_arrow draped_box
+                  fleur hand1 hand2 iron_cross left_ptr ll_angle mouse
+                  pencil pirate plus question_arrow right_ptr sb_left_arrow
+                  sb_right_arrow sb_down_arrow sb_up_arrow spider star
+                  target tcross watch xterm X_cursor)
+    :group move)
+
   (defvar move-snap-mode 'resistance
     "How to snap together window edges, one of `magnetism', `resistance', or
 `attraction'.")
@@ -98,10 +111,19 @@ its edges with an edge of another window.")
   (defvar move-resize-inhibit-configure nil
     "Only update window contents after it has stopped moving.")
 
+  ;; Locally set by place-window-interactively in placement.jl & reset
+  ;; in move-switch-to-resize
+  (defvar move-from-interactive-placement nil)
+
   (defvar move-resize-map (bind-keys (make-keymap)
                                      "Any-Off1" (lambda () (finished))
                                      "Any-Off2" (lambda () (finished))
                                      "Any-Off3" (lambda () (finished))
+                                     "Button2-Click"
+                                     (lambda () (move-switch-to-resize))
+                                     "Button3-Click"
+                                     (lambda ()
+                                       (move-vmaximize-then-finished))
                                      "Any-Move" (lambda () (motion))
                                      "Any-ESC" (lambda () (cancel))
                                      "Any-RET" (lambda () (finished))
@@ -418,6 +440,40 @@ its edges with an edge of another window.")
     (apply-changes)
     (throw 'move-resize-done t))
 
+  ;; called when B2-Click during interactive placement (see
+  ;; place-window-interactively in placement.jl)
+  ;; => switch to resizing the window
+  (define (move-switch-to-resize)
+    (when move-from-interactive-placement
+      (grab-pointer nil resize-cursor-shape)
+      (warp-cursor (1- (min (+ move-resize-x move-resize-width
+			       (car move-resize-frame))
+			    (screen-width)))
+		   (1- (min (+ move-resize-y move-resize-height
+			       (cdr move-resize-frame))
+			    (screen-height))))
+      (setq move-from-interactive-placement nil
+	    move-resize-function 'resize)
+      ))
+
+  ;; called when B3-Click during interactive placement (see
+  ;; place-window-interactively in placement.jl)
+  ;; => vertical maximize the window then map it
+  (define (move-vmaximize-then-finished)
+    (if move-from-interactive-placement
+      (let ((bottom-y (+ move-resize-y
+			 move-resize-height
+			 (cdr move-resize-frame))))
+	(apply erase-window-outline move-resize-last-outline)
+	(setq move-resize-height
+	      (if (> bottom-y (screen-height))
+		  (- move-resize-height
+		     (- bottom-y (screen-height)))
+		(+ move-resize-height
+		   (- (screen-height) bottom-y))))
+	(apply-changes)
+	(throw 'move-resize-done t))))
+
   (define (cancel)
     (if (eq move-resize-mode 'opaque)
 	(move-resize-window-to move-resize-window
@@ -534,10 +590,12 @@ its edges with an edge of another window.")
       (resize-window-with-hints* win new-wid new-hgt)))
 
   (define (double-window-size w)
+    "Resize the window to the double size."
     (unless (window-get w 'fixed-size)
       (resize-by-factor w 2)))
 
   (define (halve-window-size w)
+    "Resize the window to the halve size."
     (unless (window-get w 'fixed-size)
       (resize-by-factor w 0.5)))
 
@@ -575,8 +633,16 @@ that window."
       (when w
 	(resize-window-interactively w))))
 
+  (define (resize-window-frame-to w width height)
+    (let ((width-offset (- (car (window-frame-dimensions w))
+			  (car (window-dimensions w))))
+	  (height-offset (- (cdr (window-frame-dimensions w))
+			    (cdr (window-dimensions w)))))
+      (resize-window-to w (- width width-offset) (- height height-offset))))
+
   ;; Move Window To Center
   (define (move-window-center w)
+    "Move the window to the center from the current screen."
     (move-window-to w
                     (quotient (- (screen-width)
                                  (car (window-frame-dimensions w))) 2)
@@ -584,10 +650,22 @@ that window."
                                  (cdr (window-frame-dimensions w))) 2)))
 
   ;; resize-prompt
-  (define-command 'resize-window-prompt resize-window-with-hints*
-    #:doc "Resize window. Prompted to enter new size."
-    #:spec "%W\nNNew width:\nNNew height:")
-     
+  (define (resize-window-prompt)
+    "Resize window. Prompted to enter new size."
+    (require 'sawfish.wm.util.prompt)
+    (let* ((win (current-event-window))
+           (w-name (window-name win))
+           (old-w (car (window-dimensions win)))
+           (old-h (cdr (window-dimensions win)))
+	   (new-w (prompt #:title (format nil "Old width of window %s: %s\nEnter new width: " w-name old-w)))
+	   (new-h (prompt #:title (format nil "Old height of window %s: %s\nEnter new height: " w-name old-h))))
+      (if (and (numberp (string->number new-w))
+	       (numberp (string->number new-h)))
+	  (resize-window-with-hints* win (string->number new-w) (string->number new-h))
+	(display-message (format nil "One of the given values is not a number.")))))
+
+  (define-command 'resize-window-prompt resize-window-prompt)
+
   ;; resize-to-preset-size family
   (define (resize-window-to-preset-size x y)
     ;; The size is set beforehand in the configurator.
