@@ -1,6 +1,6 @@
 ;; edge/actions.jl -- Sets up central user interface of edge-actions
 
-;; Copyright (C) 2010 Christopher Roy Bratusek <zanghar@freenet.de>
+;; Copyright (C) 2010 Christopher Roy Bratusek <nano@jpberlin.de>
 
 ;; This file is part of sawfish.
 
@@ -16,7 +16,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with sawfish; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301 USA.
 
 (define-structure sawfish.wm.edge.actions
 
@@ -42,6 +43,7 @@
 
   (defvar while-hot-move nil)
   (defvar while-mousetrap nil)
+  (define edge-action-timer nil)
 
   (define (edge-action-call func edge while-moving)
     (case func
@@ -51,12 +53,18 @@
        (edge-flip-invoke edge func while-moving))
       ((flip-viewport)
        (edge-flip-invoke edge func while-moving))
-      ((expose-windows)
-       (expose-windows-action edge while-moving))
       ((expand-window)
        (expand-action edge))
       ((maximize-window)
        (maximize-action))
+      ((kill-window)
+       (kill-action))
+      ((iconify-window)
+       (iconify-action))
+      ((move-window-viewport)
+       (move-window-viewport-action edge))
+      ((move-window-workspace)
+       (move-window-workspace-action edge))
       ((show-desktop)
        (toggle-desktop))
       ((none/hot-spot)
@@ -65,7 +73,7 @@
        (hot-move-invoke edge))
       (t nil)))
 
-  ;; Entry point without dragging a windw
+  ;; Entry point without dragging a window
   (define (edge-action-hook-func)
     (unless (or while-hot-move
 	        while-mousetrap)
@@ -73,26 +81,41 @@
    	    (edge (get-active-edge)))
         (if corner
 	    (hot-spot-invoke corner)
-	  (cond ((or (eq edge 'left)
-	  	     (eq edge 'right))
-	         (edge-action-call left-right-edge-action edge nil))
-	        ((or (eq edge 'top)
-		     (eq edge 'bottom))
-	         (edge-action-call top-bottom-edge-action edge nil)))))))
+	  (let ((func (case edge
+	              ((left) left-edge-action)
+	              ((right) right-edge-action)
+	              ((top) top-edge-action)
+	              ((bottom) bottom-edge-action))))
+	    (setq edge-action-timer
+              (make-timer (lambda ()
+                            (setq edge-action-timer nil)
+	                    (funcall edge-action-call func edge nil))
+	                  (quotient edge-flip-delay 1000)
+                          (mod edge-flip-delay 1000))))))))
 
   ;; Entry point while dragging a window
   (define (edge-action-move-hook-func)
     (unless while-mousetrap
       (setq while-hot-move t)
       (let ((edge (get-active-edge)))
-        (cond ((or (eq edge 'left)
-		   (eq edge 'right))
-	       (edge-action-call left-right-edge-move-action edge t))
-	     ((or (eq edge 'top)
-		   (eq edge 'bottom))
-	       (edge-action-call top-bottom-edge-move-action edge t))))
+	 (let ((func (case edge
+	             ((left) left-edge-move-action)
+	             ((right) right-edge-move-action)
+	             ((top) top-edge-move-action)
+	             ((bottom) bottom-edge-move-action))))
+	   (setq edge-action-timer
+            (make-timer (lambda ()
+                          (setq edge-action-timer nil)
+	                  (funcall edge-action-call func edge t))
+	                (quotient edge-flip-delay 1000)
+                        (mod edge-flip-delay 1000))))
       ;; for one second after HotMove prevent HotSpot
-      (make-timer (lambda () (setq while-hot-move nil)) 1)))
+      (make-timer (lambda () (setq while-hot-move nil)) 1))))
+
+  (define (edge-action-unhook-func)
+    (when edge-action-timer
+      (delete-timer edge-action-timer)
+      (setq edge-action-timer nil)))
 
   (define (activate-edges init)
     (if init
@@ -100,6 +123,8 @@
 	  (activate-flippers t)
 	  (unless (in-hook-p 'enter-flipper-hook edge-action-hook-func)
 	    (add-hook 'enter-flipper-hook edge-action-hook-func))
+	  (unless (in-hook-p 'leave-flipper-hook edge-action-unhook-func)
+	    (add-hook 'leave-flipper-hook edge-action-unhook-func))
 	  ;; While the pointer is grabbed, window enter/leave events
 	  ;; are not generated.
 	  (unless (in-hook-p 'while-moving-hook edge-action-move-hook-func)
