@@ -84,7 +84,7 @@
 	       )
      (focus ,(_ "Focus")
             (raise-on-focus boolean)
-            (focus-when-mapped boolean)
+            (focus-when-mapped (choice always never))
             (never-focus boolean)
             (focus-click-through boolean)
             (focus-mode ,(lambda () `(choice ,@focus-modes)))
@@ -94,6 +94,7 @@
                                 `(choice ,@(mapcar car match-window-types))))
                  (frame-style ,(lambda ()
                                  `(symbol ,@(find-all-frame-styles t))))
+		 (window-type (choice normal dialog dock desktop menu toolbar utility splashscreen))
 		 (title-position (choice top bottom right left))
 		 (dimensions (pair (number 1) (number 1)))
 		 (maximized (choice all vertical horizontal
@@ -111,6 +112,7 @@
             (group ,(lambda ()
                       `(symbol ,@(delete-if-not symbolp (window-group-ids)))))
             (tab-group string)
+            (force-tab boolean)
             (ungrouped boolean)
             (cycle-skip boolean)
             (window-list-skip boolean)
@@ -121,7 +123,7 @@
             (ignore-stacking-requests boolean)
 	    (auto-gravity boolean)
 	    (never-delete boolean)
-	    (never-expose boolean)
+	    (never-tile boolean)
 	    )))
 
   ;; alist of (PROPERTY . FEATURE) mapping properties to the lisp
@@ -398,6 +400,35 @@
         ;; translate from 1.. to 0..
         (set-window-workspaces w (list (1- value))))))
 
+  (define-match-window-setter 'window-type
+    (lambda (w prop value)
+      (declare (unused prop))
+      (cond ((eq value 'normal)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_NORMAL) 'ATOM 32)
+         (set-window-type w 'default))
+	    ((eq value 'dialog)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_DIALOG) 'ATOM 32)
+         (mark-window-as-transient w))
+        ((eq value 'dock)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_DOCK) 'ATOM 32)
+         (mark-window-as-dock w))
+        ((eq value 'desktop)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_DESKTOP) 'ATOM 32)
+         (mark-window-as-desktop w))
+        ((eq value 'menu)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_MENU) 'ATOM 32)
+         (set-window-type w 'menu))
+        ((eq value 'toolbar)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_TOOLBAR) 'ATOM 32)
+         (set-window-type w 'toolbar))
+        ((eq value 'utility)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_UTILITY) 'ATOM 32)
+         (set-window-type w 'utility))
+        ((eq value 'splashscreen)
+	     (set-x-property w '_NET_WM_WINDOW_TYPE (vector '_NET_WM_WINDOW_TYPE_SPLASHSCREEN) 'ATOM 32)
+         (set-window-type w 'splash)
+         (window-put w 'place-mode 'centered)))))
+
   (define-match-window-setter 'position
     (lambda (w prop value)
       (declare (unused prop))
