@@ -16,7 +16,7 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with sawfish; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, 
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 ;; Boston, MA 02110-1301 USA.
 
 (define-structure sawfish.wm.focus
@@ -62,10 +62,20 @@
     :type boolean
     :group focus)
 
+  (defvar focus-xcycle-timestamp (cons (current-time) (current-utime))
+    ;; current-utime can overflow librep's integer, which is 30-bit if minimal.
+    ;; To be safe, current-time is used, too.
+    "Used only to support x-cycle.jl.")
 
-  ;; Only used by x-cycle.jl
-  (defvar focus-ignore-pointer-events nil
-    "When true, pointer in/out events don't cause focus changes.")
+  (define (ignore-pointer-events)
+    ;; Only necessary to support x-cycle.jl
+    ;; Returns t if current-time is later than focus-xcycle-timestamp
+    (prog1
+	(and focus-xcycle-timestamp
+	     (or (> (current-utime) (cdr focus-xcycle-timestamp))
+		 (time-later-p (current-time) (car focus-xcycle-timestamp))
+		 ))
+      (setq focus-xcycle-timestamp nil)))
 
   (define focus-within-click-event (make-fluid nil)
           "When true, the current command is being called from within
@@ -144,39 +154,16 @@ EVENT-NAME)', where EVENT-NAME may be one of the following symbols:
 
 ;;; modes
 
-  #|
-  From sawfish-1.5.0, enter-notify events invoked by grab are
-  ignored in enter-exit and enter-only. This has a down side, too,
-  but first let us see what's the intention.
-
-  The problem that this solves is when you press Alt F2 in KDE, the
-  Run Command popup appears and gets focused (if focus-when-mapped is
-  non-nil), you start typing, the completion list pops up and takes
-  focus, then you type a bit further and the completion list
-  disappears.  Focus used to revert to the window the pointer was in,
-  which usually was not the Run Command popup.  transient-unmap-window
-  tries hard to get it right, then the grab-induced enter-notify
-  brought focus to the wrong window anyway.
-
-  The problem that this causes is when you open the KDE main menu by
-  clicking the K icon in the panel, move the mouse into some
-  application window and click to dismiss the open menu, focus reverts
-  to the panel. You have to move the pointer out of the application
-  window and back in to get it focused.
-  |#
   (define-focus-mode 'enter-exit
-    (lambda (w action . args)
+    ;; `pointer-out' should not be caught. `enter-root' handles it.
+    ;; Furthermore, pointer-out used to make troubles: for example,
+    ;; an appearance of a menu by alt-key which covers the pointer
+    ;; made the focus lost.
+    (lambda (w action)
       (case action
 	((pointer-in)
-	 (when (and (window-really-wants-input-p w)
-		    ;; ignore grab/ungrab enter events
-		    ;; See the above long comment
-		    (eq (car args) 'normal))
+	 (when (window-really-wants-input-p w)
 	   (set-input-focus w)))
-	((pointer-out)
-	 ;; ignore grab/ungrab leave events
-	 (when (eq (car args) 'normal)
-	   (set-input-focus nil)))
 	((enter-root)
 	 ;; ensure that any desktop window gets focused
 	 (set-input-focus w))
@@ -190,13 +177,10 @@ EVENT-NAME)', where EVENT-NAME may be one of the following symbols:
            (set-input-focus w))))))
 
   (define-focus-mode 'enter-only
-    (lambda (w action . args)
+    (lambda (w action)
       (case action
 	((pointer-in)
-	 (when (and (window-really-wants-input-p w)
-		    ;; ignore grab/ungrab enter events
-		    ;; See the comment above enter-exit
-		    (eq (car args) 'normal))
+	 (when (window-really-wants-input-p w)
 	   (set-input-focus w)))
 	((warp-if-necessary)
 	 (let ((current (query-pointer-window)))
@@ -279,14 +263,14 @@ EVENT-NAME)', where EVENT-NAME may be one of the following symbols:
 ;;; hooks
 
   (define (focus-enter-fun w mode)
-    (unless focus-ignore-pointer-events
+    (unless (ignore-pointer-events)
       (cond ((desktop-window-p w)
 	     (focus-invoke-mode w 'enter-root mode))
 	    ((windowp w)
 	     (focus-invoke-mode w 'pointer-in mode)))))
 
   (define (focus-leave-fun w mode)
-    (unless focus-ignore-pointer-events
+    (unless (ignore-pointer-events)
       (cond ((desktop-window-p w)
 	     (focus-invoke-mode w 'leave-root mode))
 	    ((windowp w)
