@@ -1,6 +1,6 @@
 ;; kde-int.jl -- KDE integration
 
-;; Copyright (C) 2010 Christopher Roy Bratusek <nano@tuxfamily.org>
+;; Copyright (C) 2010 Christopher Roy Bratusek <nano@jpberlin.de>
 
 ;; This file is part of sawfish.
 
@@ -22,7 +22,8 @@
 (define-structure sawfish.wm.integration.kde
 
     (export detect-kde
-	    kde-late-init)
+	    kde-late-init
+	    kde-window-matchers)
 
     (open rep
 	  rep.system
@@ -31,7 +32,8 @@
           sawfish.wm.custom
           sawfish.wm.commands
           sawfish.wm.commands.launcher
-	  sawfish.wm.ext.apps-menu)
+	  sawfish.wm.ext.apps-menu
+          sawfish.wm.ext.match-window)
 
   (define-structure-alias kde-int sawfish.wm.integration.kde)
 
@@ -39,6 +41,21 @@
     '("/usr/share/applications/kde4/")
     "KDE specific directories where *.desktop files are stored.")
 
+  (define (kde-window-matchers)
+    ;; window matchers so we properly interact with plasma stuff
+    (add-window-matcher '((WM_CLASS . "^krunner/krunner$"))
+     '((focus-mode . click)
+       (never-tile . t)))
+    (add-window-matcher '((WM_CLASS . "^Plasma-desktop/plasma-desktop$"))
+     '((focus-mode . click)
+       (never-tile . t)))
+    (add-window-matcher '((WM_CLASS . "^Plasma/Plasma$"))
+     '((focus-mode . click)
+       (never-tile . t)))
+    (add-window-matcher '((WM_CLASS . "^plasmashell/plasmashell$"))
+     '((focus-mode . click)
+       (never-tile . t))))
+
   (define (init)
     (let (menu
 	  kde-logout-cmd)
@@ -90,6 +107,8 @@
   ;; If detected, returns t, and do also kde support init.
   (define (detect-kde)
     (when (or (equal (getenv "XDG_CURRENT_DESKTOP") "KDE")
+              (equal (getenv "DESKTOP_SESSION") "sawfish-kde4")
+              (equal (getenv "DESKTOP_SESSION") "sawfish-kde5")
               (getenv "KDE_FULL_SESSION"))
       (init)
       t))
@@ -97,4 +116,5 @@
   ;; Should be called after user customization is read.
   (define (kde-late-init)
     (setq desktop-directory
-	  (append desktop-directory kde-desktop-directories))))
+	  (append desktop-directory kde-desktop-directories))
+    (kde-window-matchers)))
