@@ -16,7 +16,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with sawfish; see the file COPYING.  If not, write to
-;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, 
+;; Boston, MA 02110-1301 USA.
 
 (define-structure sawfish.wm.state.wm-spec
 
@@ -167,7 +168,7 @@
     (let* ((limits (workspace-limits))
 	   (port (screen-viewport))
            ;; Since vp size can vary from workspace to workspace, use
-           ;; the maximum dimensions accross all workspaces.
+           ;; the maximum dimensions across all workspaces.
 	   (port-size (let ((dims (cons viewport-dimensions
                                         (mapcar (lambda (e)
                                                   (unless (eq (car e)
