@@ -119,15 +119,12 @@
           iconify-whole-group uniconify-whole-group
           always-update-frames edge-flip-warp-pointer
           frame-type-fallbacks warp-to-window-x-offset
-          warp-to-window-y-offset uniquify-name-format
-          transients-get-focus decorate-transients
+          warp-to-window-y-offset uniquify-name-format transients-get-focus 
           raise-windows-on-uniconify uniconify-to-current-workspace
           iconify-ignored focus-ignore-pointer-events
           focus-windows-on-uniconify transients-are-group-members
-          raise-selected-windows warp-to-selected-windows
-          menus-include-shortcuts configure-auto-gravity
-          configure-ignore-stacking-requests
-          beos-window-menu-simplifies customize-show-symbols
+          raise-selected-windows warp-to-selected-windows configure-auto-gravity
+          configure-ignore-stacking-requests beos-window-menu-simplifies
           move-snap-mode move-snap-ignored-windows
           move-resize-inhibit-configure move-snap-edges
           raise-windows-when-unshaded persistent-group-ids
